@@ -3,6 +3,7 @@ package yqlib
 import (
 	"container/list"
 	"fmt"
+	"strings"
 
 	"github.com/jinzhu/copier"
 	yaml "gopkg.in/yaml.v3"
@@ -33,6 +34,21 @@ func (n *CandidateNode) GetKey() string {
 	return fmt.Sprintf("%v%v - %v", keyPrefix, n.Document, n.Path)
 }
 
+func (n *CandidateNode) GetNiceTag() string {
+	return unwrapDoc(n.Node).Tag
+}
+
+func (n *CandidateNode) GetNicePath() string {
+	if n.Path != nil && len(n.Path) >= 0 {
+		pathStr := make([]string, len(n.Path))
+		for i, v := range n.Path {
+			pathStr[i] = fmt.Sprintf("%v", v)
+		}
+		return strings.Join(pathStr, ".")
+	}
+	return ""
+}
+
 func (n *CandidateNode) AsList() *list.List {
 	elMap := list.New()
 	elMap.PushBack(n)
@@ -40,7 +56,7 @@ func (n *CandidateNode) AsList() *list.List {
 }
 
 func (n *CandidateNode) CreateChildInMap(key *yaml.Node, node *yaml.Node) *CandidateNode {
-	var value interface{} = nil
+	var value interface{}
 	if key != nil {
 		value = key.Value
 	}
