@@ -8,15 +8,19 @@ CGO_ENABLED=0 gox -ldflags "${LDFLAGS}" -output="build/yq_{{.OS}}_{{.Arch}}" --o
 
 cd build
 
-find . -executable -type f | xargs -I {} tar czvf {}.tar.gz {}
+find . -executable -type f | xargs -I {} tar czvf {}.tar.gz {} yq.1 -C ../scripts install-man-page.sh
+tar czvf yq_man_page_only.tar.gz yq.1 -C ../scripts install-man-page.sh
 
 rhash -r -a . -o checksums
 
 rhash --list-hashes > checksums_hashes_order
 
+cp ../scripts/extract-checksum.sh .
+
 # just in case find thinks this is executable...
 rm -f checksums_hashes_order.tar.gz 
 rm -f checksums.tar.gz
+rm yq.1 
 
 rm yq_windows_386.exe.tar.gz
 rm yq_windows_amd64.exe.tar.gz
